J = 100; %Number of grid points
y = 0:1/(J+1):1; %values of x at grid points
dx = 1/(J+1); %Spatial step
dt = 0.01; %Choose whatever you like < 0.1 (unconditionally stable)
s = dt/dx^2;

T = 1; %Final time
M = floor(T/dt); %Number of iterations

%Set up matrix for implicit scheme
A = eye(J)*(1+2*s); %Identity matrix times (1+2s)
for i=1:J-1  %Set off diagonal entries
   A(i+1,i)=-s;
   A(i,i+1)=-s;
end

x = y(2:end-1);
f = double(x>0.5)'; %Initial heat distribution

ymin = min(f);
ymax = max(f);

plot(y,[0;f;0]);
pause;
key_pressed=0;
set(gcf, 'KeyPressFcn', 'key_pressed=mod(key_pressed+1,2);')

u=f;   %Initial condition

%Press any key to stop/start simulation
for i=1:M
   
   u = A\u;  %Implicit iteration solves scheme Au^(n+1) = u^n
             %Note: x=A\b solves system Ax=b in Matlab
   %Draw u
   plot(y,[0;u;0]);
   ylim([ymin ymax]);
   drawnow;
   pause(40*dt)
    
   %Pause when key is pressed
   while key_pressed == 1
       pause(0.1);
   end
end


